@@ -75,7 +75,6 @@ const char *ast_setlocale(const char *locale);
  * \param len Size of the chunk of memory buf.
  * \param format A string specifying the format of time to be placed into buf.
  * \param tm Pointer to the broken out time to be used for the format.
- * \param locale Text string specifying the locale to be used for language strings.
  * \retval An integer value specifying the number of bytes placed into buf or -1 on error.
  */
 int ast_strftime(char *buf, size_t len, const char *format, const struct ast_tm *tm);
@@ -87,7 +86,6 @@ int ast_strftime_locale(char *buf, size_t len, const char *format, const struct
  * \param s A string specifying some portion of a date and time.
  * \param format The format in which the string, s, is expected.
  * \param tm The broken-out time structure into which the parsed data is expected.
- * \param locale Text string specifying the locale to be used for language strings.
  * \retval A pointer to the first character within s not used to parse the date and time.
  */
 char *ast_strptime(const char *s, const char *format, struct ast_tm *tm);
@@ -101,4 +99,9 @@ char *ast_strptime_locale(const char *s, const char *format, struct ast_tm *tm,
 struct ast_test;
 void ast_localtime_wakeup_monitor(struct ast_test *info);
 
+/*! \brief ast_strftime for ISO8601 formatting timestamps. */
+#define AST_ISO8601_FORMAT "%FT%T.%q%z"
+/*! \brief Max length of an null terminated, millisecond resolution, ISO8601 timestamp string. */
+#define AST_ISO8601_LEN 29
+
 #endif /* _ASTERISK_LOCALTIME_H */
