@@ -85,6 +85,16 @@ struct ao2_container *stasis_app_get_all(void);
  */
 struct stasis_app *stasis_app_get_by_name(const char *name);
 
+/*!
+ * \brief Check if a Stasis application is registered.
+ *
+ * \param name The name of the registered Stasis application
+ *
+ * \return 1 if the application is registered.
+ * \return 0 if the application is not registered.
+ */
+int stasis_app_is_registered(const char *name);
+
 /*!
  * \brief Register a new Stasis application.
  *
@@ -116,7 +126,7 @@ int stasis_app_register(const char *app_name, stasis_app_cb handler, void *data)
 int stasis_app_register_all(const char *app_name, stasis_app_cb handler, void *data);
 
 /*!
- * \brief Unregister a Stasis application.
+ * \brief Unregister a Stasis application and unsubscribe from all event sources.
  * \param app_name Name of the application to unregister.
  */
 void stasis_app_unregister(const char *app_name);
@@ -447,6 +457,20 @@ void stasis_app_control_execute_until_exhausted(
 int stasis_app_control_is_done(
 	struct stasis_app_control *control);
 
+/*!
+ * \brief Set the failed flag on a control structure
+ *
+ * \param control Control object to be updated
+ */
+void stasis_app_control_mark_failed(struct stasis_app_control *control);
+
+/*!
+ * \brief Check if a control object is marked as "failed"
+ *
+ * \param control Control object to check
+ */
+int stasis_app_control_is_failed(const struct stasis_app_control *control);
+
 /*!
  * \brief Flush the control command queue.
  * \since 13.9.0
